@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package HTTP::BrowserDetect;
-$HTTP::BrowserDetect::VERSION = '2.01';
+$HTTP::BrowserDetect::VERSION = '2.02';
 use vars qw(@ALL_TESTS);
 
 # Operating Systems
@@ -323,7 +323,7 @@ sub new {
         $user_agent = $ENV{'HTTP_USER_AGENT'};
     }
 
-    $self->{user_agent} = $user_agent;
+    $self->{user_agent} = $user_agent // '';
     $self->_init_core;
 
     return $self;
@@ -2390,7 +2390,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 2.01
+version 2.02
 
 =head1 SYNOPSIS
 
